@@ -3,16 +3,14 @@ from . import _utils
 
 def beskeder(self, id=None):
     if id != None:
-        if "-" in str(id):
-            url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx?type=&elevid={self.elevId}&selectedfolderid={id}"
-        else:
-            url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx?type=selecthold&elevid={self.elevId}&holdid={id}"
+        url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx?mappeid={id}"
     else:
-        url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx?type=liste&elevid={self.elevId}"
+        url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx"
 
     resp = self.session.get(url)
-    if resp.url != url:
+    if url not in resp.url:
         raise Exception("lectio-cookie udløbet")
+
     soup = BeautifulSoup(resp.text, "html.parser")
 
     beskederHtml = soup.find_all("tr")
@@ -29,7 +27,7 @@ def beskeder(self, id=None):
         resp = self.session.post(url, data=payload)
         soup = BeautifulSoup(resp.text, "html.parser")
 
-        beskederHtml = soup.find_all("tr")[2:-2]
+        beskederHtml = soup.find_all("tr")[:-2]
 
     options = []
     for div in soup.find("div", {"id": "s_m_Content_Content_ListGridSelectionTree"}).find_all("div", {
@@ -96,23 +94,27 @@ def calculateSpacing(besked, beskedOversigt, spacing=0):
         return spacing
 
 def besked(self, message_id):
-    url = f"https://www.lectio.dk/lectio/{self.skoleId}/beskeder2.aspx?type=showthread&elevid={self.elevId}&id={message_id}"
+    url = f"https://www.lectio.dk/lectio/681/beskeder2.aspx?type=visbesked&id={message_id}"
     resp = self.session.get(url)
     if resp.url != url:
         raise Exception("lectio-cookie udløbet")
     soup = BeautifulSoup(resp.text, "html.parser")
 
     beskeder = []
-    beskederHtml = soup.find("table", {"id": "s_m_Content_Content_MessageThreadCtrlId_MessagesGV"}).find_all("tr")
+    beskederHtml = soup.find("table", {"id": "s_m_Content_Content_MessageThreadCtrl_MessagesGV"}).find_all("tr")
+    if soup.find("span", {"class": "grayed-out"}).text != "Denne tråd kan ikke besvares":
+        beskederHtml = beskederHtml[:-1]
 
     beskedOversigt = {}
-    for besked in soup.find("table", {"id": "s_m_Content_Content_MessageThreadCtrlId_MessagesGV"}).find_all("tr")[:-1]:
+    for besked in beskederHtml:
         try:
-            beskedOversigt[besked.find("div", {"class": "message-thread-message-sender"}).text.strip()] = besked.find("div", {"class": "message-reply-summary viewed-persons-message"}).text.replace("Er svar på besked af ", "").strip()
+            beskedOversigt[besked.find("div", {"class": "message-thread-message-sender"}).text.strip()] = besked.find(
+                "div", {"class": "message-reply-summary viewed-persons-message"}).text.replace("Er svar på besked af ",
+                                                                                               "").strip()
         except Exception:
             beskedOversigt[besked.find("div", {"class": "message-thread-message-sender"}).text.strip()] = None
 
-    for besked in beskederHtml[:-1]:
+    for besked in beskederHtml:
         bruger = {"navn": besked.find("div", {"class": "message-thread-message-sender"}).find("span").text, "id": besked.find("div", {"class": "message-thread-message-sender"}).find("span").get("data-lectiocontextcard")}
         try:
             besvarelse = besked.find("div", {"class": "message-reply-summary viewed-persons-message"}).text.replace("Er svar på besked af ", "").strip()
@@ -152,7 +154,7 @@ def besked(self, message_id):
             sortedBeskeder.append(besked)
 
     beskedDict = {
-        "modtagere": ", ".join([str(modtager.text) for modtager in soup.find("div", {"id": "s_m_Content_Content_MessageThreadCtrlId_RecipientsReadMode"}) if len(modtager.text.strip().replace(",", "")) > 0]).strip(),
+        "modtagere": ", ".join([str(modtager.text) for modtager in soup.find("div", {"id": "s_m_Content_Content_MessageThreadCtrl_RecipientsReadMode"}) if len(modtager.text.strip().replace(",", "")) > 0]).strip(),
         "beskeder": sortedBeskeder
     }
 
